searchData={"items":[{"type":"module","title":"Literature.Cloudflare","doc":"Literature Cloudflare","ref":"Literature.Cloudflare.html"},{"type":"function","title":"Literature.Cloudflare.purge_cloudflare_files/2","doc":"Purge cloudflare files.","ref":"Literature.Cloudflare.html#purge_cloudflare_files/2"},{"type":"module","title":"Literature.DownloadHelpers","doc":"Returns:\n\n  * `{:ok, stored_file_absolute_path}` if everything were ok.\n  * `{:error, :file_size_is_too_big}` if file size exceeds `max_file_size`\n  * `{:error, :download_failure}` if host isn't reachable\n  * `{:error, :eexist}` if file exists already\n\nOptions:\n\n  * `max_file_size` - max available file size for downloading (in bytes). Default is `1024 * 1024 * 1000` (1GB)\n  * `path` - absolute file path for the saved file. Default is `pwd   requested file name`","ref":"Literature.DownloadHelpers.html"},{"type":"module","title":"Examples - Literature.DownloadHelpers","doc":"iex> Literature.DownloadHelpers.download_image(\"http://speedtest.ftp.otenet.gr/files/test100k.db\")\n    {:ok, \"/absolute/path/to/test_100k.db\"}\n\n    iex> Literature.DownloadHelpers.download_image(\"http://speedtest.ftp.otenet.gr/files/test100k.db\", [max_file_size: 99 * 1000])\n    {:error, :file_size_is_too_big}\n\n    iex> Literature.DownloadHelpers.download_image(\"http://speedtest.ftp.otenet.gr/files/test100k.db\", [path: \"/custom/absolute/file/path.db\"])\n    {:ok, \"/custom/absolute/file/path.db\"}","ref":"Literature.DownloadHelpers.html#module-examples"},{"type":"function","title":"Literature.DownloadHelpers.download_image/2","doc":"","ref":"Literature.DownloadHelpers.html#download_image/2"},{"type":"behaviour","title":"Literature.Migration","doc":"Migrations create the database tables Literature needs.","ref":"Literature.Migration.html"},{"type":"behaviour","title":"Usage - Literature.Migration","doc":"To use migrations in your application you'll need to generate an `Ecto.Migration` that wraps\ncalls to `Literature.Migrations`:\n\n```bash\nmix ecto.gen.migration add_literature\n```\n\nOpen the generated migration in your editor and call the `up` and `down` functions on\n`Literature.Migrations`:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddLiterature do\n  use Ecto.Migration\n  \n  def up, do: Literature.Migrations.up(version: 1)\n  \n  def down, do: Literature.Migrations.down(version: 1)\nend\n```\n\nThis will run the migrations for your database.\n\nNow, run the migration to create the table:\n\n```bash\nmix ecto.migrate\n```","ref":"Literature.Migration.html#module-usage"},{"type":"function","title":"Literature.Migration.down/1","doc":"","ref":"Literature.Migration.html#down/1"},{"type":"callback","title":"Literature.Migration.down/1","doc":"","ref":"Literature.Migration.html#c:down/1"},{"type":"function","title":"Literature.Migration.migrated_version/1","doc":"","ref":"Literature.Migration.html#migrated_version/1"},{"type":"callback","title":"Literature.Migration.migrated_version/1","doc":"","ref":"Literature.Migration.html#c:migrated_version/1"},{"type":"function","title":"Literature.Migration.up/1","doc":"","ref":"Literature.Migration.html#up/1"},{"type":"callback","title":"Literature.Migration.up/1","doc":"","ref":"Literature.Migration.html#c:up/1"},{"type":"module","title":"Literature.Migrations.Postgres","doc":"update @current_version if adding new migration","ref":"Literature.Migrations.Postgres.html"},{"type":"module","title":"Literature.Migrations.Postgres.V01","doc":"Beginning tables for Literature","ref":"Literature.Migrations.Postgres.V01.html"},{"type":"function","title":"Literature.Migrations.Postgres.V01.down/1","doc":"","ref":"Literature.Migrations.Postgres.V01.html#down/1"},{"type":"function","title":"Literature.Migrations.Postgres.V01.up/1","doc":"","ref":"Literature.Migrations.Postgres.V01.html#up/1"},{"type":"module","title":"Literature.Migrations.Postgres.V02","doc":"Adds more indexes","ref":"Literature.Migrations.Postgres.V02.html"},{"type":"function","title":"Literature.Migrations.Postgres.V02.down/1","doc":"","ref":"Literature.Migrations.Postgres.V02.html#down/1"},{"type":"function","title":"Literature.Migrations.Postgres.V02.up/1","doc":"","ref":"Literature.Migrations.Postgres.V02.html#up/1"},{"type":"module","title":"Literature.Repo","doc":"Wrappers around `Ecto.Repo` callbacks.\n\nThese functions should be used when working with an Ecto repo. These functions\nwill resolve the correct repo instance, and set the schema prefix and the log level, according\nto the Literature configuration.","ref":"Literature.Repo.html"},{"type":"function","title":"Literature.Repo.all/2","doc":"Wraps `c:Ecto.Repo.all/2`.","ref":"Literature.Repo.html#all/2"},{"type":"function","title":"Literature.Repo.delete/2","doc":"Wraps `c:Ecto.Repo.delete/2`.","ref":"Literature.Repo.html#delete/2"},{"type":"function","title":"Literature.Repo.get/2","doc":"Wraps `c:Ecto.Repo.get/2`.","ref":"Literature.Repo.html#get/2"},{"type":"function","title":"Literature.Repo.get_by/2","doc":"Wraps `c:Ecto.Repo.get_by/2`.","ref":"Literature.Repo.html#get_by/2"},{"type":"function","title":"Literature.Repo.insert/2","doc":"Wraps `c:Ecto.Repo.insert/2`.","ref":"Literature.Repo.html#insert/2"},{"type":"function","title":"Literature.Repo.paginate/2","doc":"Wraps `c:Ecto.Repo.paginate/2`.","ref":"Literature.Repo.html#paginate/2"},{"type":"function","title":"Literature.Repo.preload/2","doc":"Wraps `c:Ecto.Repo.preload/2`.","ref":"Literature.Repo.html#preload/2"},{"type":"function","title":"Literature.Repo.update/2","doc":"Wraps `c:Ecto.Repo.update/2`.","ref":"Literature.Repo.html#update/2"},{"type":"module","title":"Literature.Router","doc":"Provides LiveView routing for literature.","ref":"Literature.Router.html"},{"type":"macro","title":"Literature.Router.literature/2","doc":"Defines a Literature route.\n\nIt requires a path where to mount the public page at and allows options to customize routing.","ref":"Literature.Router.html#literature/2"},{"type":"macro","title":"Examples - Literature.Router.literature/2","doc":"Mount a `blog` at the path \"/blog\":\n\n    defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      use Literature.Router\n\n      scope \"/\", MyAppWeb do\n        pipe_through [:browser]\n\n        literature \"/blog\"\n      end\n    end","ref":"Literature.Router.html#literature/2-examples"},{"type":"macro","title":"Literature.Router.literature_api/2","doc":"Defines a Literature API route.","ref":"Literature.Router.html#literature_api/2"},{"type":"macro","title":"Examples - Literature.Router.literature_api/2","doc":"defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      use Literature.Router\n\n      literature_api \"/api\"\n    end","ref":"Literature.Router.html#literature_api/2-examples"},{"type":"macro","title":"Literature.Router.literature_assets/1","doc":"Defines routes for Literature static assets.\n\nStatic assets should not be CSRF protected. So they need to be mounted in your\nrouter in a different pipeline.\n\nIt can take the `path` the literature assets will be mounted at.","ref":"Literature.Router.html#literature_assets/1"},{"type":"macro","title":"Usage - Literature.Router.literature_assets/1","doc":"```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport Literature.Router\n...\n\nscope \"/\" do\n  literature_assets(\"/\")\nend\n```","ref":"Literature.Router.html#literature_assets/1-usage"},{"type":"macro","title":"Literature.Router.literature_dashboard/2","doc":"Defines a Literature dashboard route.\n\nIt requires a path where to mount the dashboard at and allows options to customize routing.","ref":"Literature.Router.html#literature_dashboard/2"},{"type":"macro","title":"Examples - Literature.Router.literature_dashboard/2","doc":"Mount an `literature` dashboard at the path \"/literature\":\n\n    defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      use Literature.Router\n\n      scope \"/\", MyAppWeb do\n        pipe_through [:browser]\n\n        literature_dashboard \"/literature\"\n      end\n    end","ref":"Literature.Router.html#literature_dashboard/2-examples"},{"type":"module","title":"Literature.Uploaders","doc":"Literature Uploaders","ref":"Literature.Uploaders.html"},{"type":"function","title":"Literature.Uploaders.acl/2","doc":"","ref":"Literature.Uploaders.html#acl/2"},{"type":"function","title":"Literature.Uploaders.asset_host/0","doc":"","ref":"Literature.Uploaders.html#asset_host/0"},{"type":"function","title":"Literature.Uploaders.async/0","doc":"","ref":"Literature.Uploaders.html#async/0"},{"type":"function","title":"Literature.Uploaders.bucket/0","doc":"","ref":"Literature.Uploaders.html#bucket/0"},{"type":"function","title":"Literature.Uploaders.bucket/1","doc":"","ref":"Literature.Uploaders.html#bucket/1"},{"type":"function","title":"Literature.Uploaders.default_url/1","doc":"","ref":"Literature.Uploaders.html#default_url/1"},{"type":"function","title":"Literature.Uploaders.default_url/2","doc":"","ref":"Literature.Uploaders.html#default_url/2"},{"type":"function","title":"Literature.Uploaders.delete/1","doc":"","ref":"Literature.Uploaders.html#delete/1"},{"type":"function","title":"Literature.Uploaders.filename/2","doc":"","ref":"Literature.Uploaders.html#filename/2"},{"type":"function","title":"Literature.Uploaders.filename/3","doc":"","ref":"Literature.Uploaders.html#filename/3"},{"type":"function","title":"Literature.Uploaders.remote_file_headers/1","doc":"","ref":"Literature.Uploaders.html#remote_file_headers/1"},{"type":"function","title":"Literature.Uploaders.s3_object_headers/2","doc":"","ref":"Literature.Uploaders.html#s3_object_headers/2"},{"type":"function","title":"Literature.Uploaders.storage_dir/2","doc":"","ref":"Literature.Uploaders.html#storage_dir/2"},{"type":"function","title":"Literature.Uploaders.storage_dir_prefix/0","doc":"","ref":"Literature.Uploaders.html#storage_dir_prefix/0"},{"type":"function","title":"Literature.Uploaders.store/1","doc":"","ref":"Literature.Uploaders.html#store/1"},{"type":"function","title":"Literature.Uploaders.transform/2","doc":"","ref":"Literature.Uploaders.html#transform/2"},{"type":"function","title":"Literature.Uploaders.url/1","doc":"","ref":"Literature.Uploaders.html#url/1"},{"type":"function","title":"Literature.Uploaders.url/2","doc":"","ref":"Literature.Uploaders.html#url/2"},{"type":"function","title":"Literature.Uploaders.url/3","doc":"","ref":"Literature.Uploaders.html#url/3"},{"type":"function","title":"Literature.Uploaders.urls/2","doc":"","ref":"Literature.Uploaders.html#urls/2"},{"type":"function","title":"Literature.Uploaders.validate/1","doc":"","ref":"Literature.Uploaders.html#validate/1"},{"type":"module","title":"Literature.Uploaders.Type","doc":"","ref":"Literature.Uploaders.Type.html"},{"type":"function","title":"Literature.Uploaders.Type.cast/1","doc":"","ref":"Literature.Uploaders.Type.html#cast/1"},{"type":"function","title":"Literature.Uploaders.Type.dump/1","doc":"","ref":"Literature.Uploaders.Type.html#dump/1"},{"type":"function","title":"Literature.Uploaders.Type.embed_as/1","doc":"","ref":"Literature.Uploaders.Type.html#embed_as/1"},{"type":"function","title":"Literature.Uploaders.Type.equal?/2","doc":"","ref":"Literature.Uploaders.Type.html#equal?/2"},{"type":"function","title":"Literature.Uploaders.Type.load/1","doc":"","ref":"Literature.Uploaders.Type.html#load/1"},{"type":"function","title":"Literature.Uploaders.Type.type/0","doc":"","ref":"Literature.Uploaders.Type.html#type/0"},{"type":"module","title":"Literature.Workers.DownloadWorker","doc":"pool boy worker that handles image proccessing and stores it in temp file","ref":"Literature.Workers.DownloadWorker.html"},{"type":"function","title":"Literature.Workers.DownloadWorker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Literature.Workers.DownloadWorker.html#child_spec/1"},{"type":"function","title":"Literature.Workers.DownloadWorker.init/1","doc":"","ref":"Literature.Workers.DownloadWorker.html#init/1"},{"type":"function","title":"Literature.Workers.DownloadWorker.start_link/1","doc":"","ref":"Literature.Workers.DownloadWorker.html#start_link/1"},{"type":"exception","title":"Literature.PageNotFound","doc":"Raised when a page is not found.","ref":"Literature.PageNotFound.html"}],"content_type":"text/markdown"}